@@ -1,5 +1,4 @@
 import os
-import re
 import sys
 
 from pipenv import environments
@@ -16,30 +15,30 @@ from pipenv.cli.options import (
     pypi_mirror_option,
     python_option,
     site_packages_option,
-    skip_lock_option,
     sync_options,
     system_option,
     uninstall_options,
     upgrade_options,
     verbose_option,
 )
-from pipenv.utils.dependencies import get_lockfile_section_using_pipfile_category
+from pipenv.utils import console, err
 from pipenv.utils.environment import load_dot_env
 from pipenv.utils.processes import subprocess_run
-from pipenv.vendor import click
 from pipenv.vendor.click import (
     Choice,
     argument,
-    echo,
     edit,
     group,
     option,
     pass_context,
-    secho,
-    style,
     version_option,
 )
 
+with console.capture() as capture:
+    console.print("[bold]pipenv[/bold]", end="")
+
+prog_name = capture.get()
+
 subcommand_context = CONTEXT_SETTINGS.copy()
 subcommand_context.update({"ignore_unknown_options": True, "allow_extra_args": True})
 subcommand_context_no_interspersion = subcommand_context.copy()
@@ -64,7 +63,7 @@ subcommand_context_no_interspersion["allow_interspersed_args"] = False
     help="Output diagnostic information for use in GitHub issues.",
 )
 @general_options
-@version_option(prog_name=style("pipenv", bold=True), version=__version__)
+@version_option(prog_name=prog_name, version=__version__)
 @pass_state
 @pass_context
 def cli(
@@ -82,7 +81,6 @@ def cli(
     site_packages=None,
     **kwargs,
 ):
-    from pipenv.patched.pip._vendor import rich
     from pipenv.utils.shell import system_which
 
     load_dot_env(state.project, quiet=state.quiet)
@@ -93,10 +91,9 @@ def cli(
     from pipenv.utils.virtualenv import cleanup_virtualenv, do_where, warn_in_virtualenv
 
     if "PIPENV_COLORBLIND" in os.environ:
-        echo(
+        err.print(
             "PIPENV_COLORBLIND is deprecated, use NO_COLOR"
             " per https://no-color.org/ instead",
-            err=True,
         )
 
     if man:
@@ -105,25 +102,20 @@ def cli(
             os.execle(system_which("man"), "man", path, os.environ)
             return 0
         else:
-            secho(
-                "man does not appear to be available on your system.",
-                fg="yellow",
-                bold=True,
-                err=True,
+            err.print(
+                "man does not appear to be available on your system.", style="bold yellow"
             )
             return 1
     if envs:
-        echo("The following environment variables can be set, to do various things:\n")
+        console.print(
+            "The following environment variables can be set, to do various things:\n"
+        )
         for key in state.project.__dict__:
             if key.startswith("PIPENV"):
-                echo(f"  - {style(key, bold=True)}")
-        echo(
-            "\nYou can learn more at:\n   {}".format(
-                style(
-                    "https://pipenv.pypa.io/en/latest/advanced/#configuration-with-environment-variables",
-                    fg="green",
-                )
-            )
+                console.print(f"  - {key}", style="bold")
+        console.print(
+            "\nYou can learn more at:\n   "
+            "[green]https://pipenv.pypa.io/en/latest/advanced/#configuration-with-environment-variables[/green]",
         )
         return 0
     warn_in_virtualenv(state.project)
@@ -133,7 +125,7 @@ def cli(
             do_where(state.project, bare=True)
             return 0
         elif py:
-            do_py(state.project, ctx=ctx)
+            do_py(state.project, ctx=ctx, bare=True)
             return 0
         # --support was passed...
         elif support:
@@ -149,57 +141,39 @@ def cli(
         elif venv:
             # There is no virtualenv yet.
             if not state.project.virtualenv_exists:
-                echo(
-                    "{}({}){}".format(
-                        style(
-                            "No virtualenv has been created for this project", fg="red"
-                        ),
-                        style(state.project.project_directory, bold=True),
-                        style(" yet!", fg="red"),
-                    ),
-                    err=True,
+                err.print(
+                    "[red]No virtualenv has been created for this project[/red]"
+                    f"[bold]{state.project.project_directory}[/bold]"
+                    " [red]yet![/red]"
                 )
                 ctx.abort()
             else:
-                echo(state.project.virtualenv_location)
+                print(state.project.virtualenv_location)
                 return 0
         # --rm was passed...
         elif rm:
             # Abort if --system (or running in a virtualenv).
             if state.project.s.PIPENV_USE_SYSTEM or environments.is_in_virtualenv():
-                echo(
-                    style(
-                        "You are attempting to remove a virtualenv that "
-                        "Pipenv did not create. Aborting.",
-                        fg="red",
-                    )
+                console.print(
+                    "You are attempting to remove a virtualenv that "
+                    "Pipenv did not create. Aborting.",
+                    style="red",
                 )
                 ctx.abort()
             if state.project.virtualenv_exists:
                 loc = state.project.virtualenv_location
-                echo(
-                    style(
-                        "{} ({})...".format(
-                            style("Removing virtualenv", bold=True),
-                            style(loc, fg="green"),
-                        )
-                    )
+                console.print(
+                    f"[bold]Removing virtualenv[/bold] ([green]{loc}[green])..."
                 )
 
-                console = rich.console.Console()
-                # TODO: add state.project.s to spinner status
                 with console.status("Running..."):
                     # Remove the virtualenv.
                     cleanup_virtualenv(state.project, bare=True)
                 return 0
             else:
-                echo(
-                    style(
-                        "No virtualenv has been created for this project yet!",
-                        fg="red",
-                        bold=True,
-                    ),
-                    err=True,
+                err.print(
+                    "No virtualenv has been created for this project yet!",
+                    style="red bold",
                 )
                 ctx.abort()
     # --python was passed...
@@ -215,7 +189,7 @@ def cli(
     # Check this again before exiting for empty ``pipenv`` command.
     elif ctx.invoked_subcommand is None:
         # Display help to user, if no commands were passed.
-        echo(format_help(ctx.get_help()))
+        print(format_help(ctx.get_help()))
 
 
 @cli.command(
@@ -225,11 +199,11 @@ def cli(
 @system_option
 @deploy_option
 @site_packages_option
-@skip_lock_option
 @install_options
 @pass_state
 def install(state, **kwargs):
-    """Installs provided packages and adds them to Pipfile, or (if no packages are given), installs all packages from Pipfile."""
+    """Installs provided packages and adds them to Pipfile,
+    or (if no packages are given), installs all packages from Pipfile."""
     from pipenv.routines.install import do_install
 
     do_install(
@@ -239,18 +213,16 @@ def install(state, **kwargs):
         pypi_mirror=state.pypi_mirror,
         system=state.system,
         ignore_pipfile=state.installstate.ignore_pipfile,
-        skip_lock=state.installstate.skip_lock,
         requirementstxt=state.installstate.requirementstxt,
         pre=state.installstate.pre,
         deploy=state.installstate.deploy,
-        keep_outdated=state.installstate.keep_outdated,
-        selective_upgrade=state.installstate.selective_upgrade,
-        index_url=state.index,
+        index=state.index,
         packages=state.installstate.packages,
         editable_packages=state.installstate.editables,
         site_packages=state.site_packages,
         extra_pip_args=state.installstate.extra_pip_args,
         categories=state.installstate.categories,
+        skip_lock=state.installstate.skip_lock,
     )
 
 
@@ -318,10 +290,9 @@ def uninstall(ctx, state, all_dev=False, all=False, **kwargs):
         editable_packages=state.installstate.editables,
         python=state.python,
         system=state.system,
-        lock=not state.installstate.skip_lock,
+        lock=True,
         all_dev=all_dev,
         all=all,
-        keep_outdated=state.installstate.keep_outdated,
         pypi_mirror=state.pypi_mirror,
         categories=state.installstate.categories,
         ctx=ctx,
@@ -370,7 +341,6 @@ def lock(ctx, state, **kwargs):
         state.project,
         clear=state.clear,
         pre=pre,
-        keep_outdated=state.installstate.keep_outdated,
         pypi_mirror=state.pypi_mirror,
         write=not state.quiet,
         categories=state.installstate.categories,
@@ -394,16 +364,14 @@ def lock(ctx, state, **kwargs):
     default=False,
     help="Always spawn a sub-shell, even if one is already spawned.",
 )
+@option(
+    "--quiet", is_flag=True, help="Quiet standard output, except vulnerability report."
+)
 @argument("shell_args", nargs=-1)
 @pypi_mirror_option
 @python_option
 @pass_state
-def shell(
-    state,
-    fancy=False,
-    shell_args=None,
-    anyway=False,
-):
+def shell(state, fancy=False, shell_args=None, anyway=False, quiet=False):
     """Spawns a shell within the virtualenv."""
     from pipenv.routines.shell import do_shell
 
@@ -412,13 +380,10 @@ def shell(
         # If PIPENV_ACTIVE is set, VIRTUAL_ENV should always be set too.
         venv_name = os.environ.get("VIRTUAL_ENV", "UNKNOWN_VIRTUAL_ENVIRONMENT")
         if not anyway:
-            echo(
-                "{} {} {}\nNo action taken to avoid nested environments.".format(
-                    style("Shell for"),
-                    style(venv_name, fg="green", bold=True),
-                    style("already activated.", bold=True),
-                ),
-                err=True,
+            err.print(
+                f"Shell for [green bold]{venv_name}[/green bold] "
+                "[bold]already activated[/bold].\n"
+                "New shell not activated to avoid nested environments."
             )
             sys.exit(1)
     # Load .env file.
@@ -432,6 +397,7 @@ def shell(
         fancy=fancy,
         shell_args=shell_args,
         pypi_mirror=state.pypi_mirror,
+        quiet=quiet,
     )
 
 
@@ -553,6 +519,7 @@ def check(
         output=output,
         key=key,
         quiet=quiet,
+        verbose=state.verbose,
         exit_code=exit_code,
         policy_file=policy_file,
         save_json=save_json,
@@ -583,7 +550,6 @@ def update(ctx, state, bare=False, dry_run=None, outdated=False, **kwargs):
         clear=state.clear,
         pre=state.installstate.pre,
         pypi_mirror=state.pypi_mirror,
-        keep_outdated=state.installstate.keep_outdated,
         system=False,
         packages=state.installstate.packages,
         editable_packages=state.installstate.editables,
@@ -645,17 +611,17 @@ def run_open(state, module, *args, **kwargs):
         [
             state.project._which("python"),
             "-c",
-            "import {0}; print({0}.__file__)".format(module),
+            f"import {module}; print({module}.__file__)",
         ]
     )
     if c.returncode:
-        echo(style("Module not found!", fg="red"))
+        console.print("Module not found!", style="red")
         sys.exit(1)
     if "__init__.py" in c.stdout:
         p = os.path.dirname(c.stdout.strip().rstrip("cdo"))
     else:
         p = c.stdout.strip().rstrip("cdo")
-    echo(style(f"Opening {p!r} in your EDITOR.", bold=True))
+    console.print(f"Opening {p!r} in your EDITOR.", style="bold")
     inline_activate_virtual_environment(state.project)
     edit(filename=p)
     return 0
@@ -668,6 +634,7 @@ def run_open(state, module, *args, **kwargs):
 @system_option
 @option("--bare", is_flag=True, default=False, help="Minimal output.")
 @sync_options
+@site_packages_option
 @pass_state
 @pass_context
 def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
@@ -679,7 +646,6 @@ def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
         dev=state.installstate.dev,
         python=state.python,
         bare=bare,
-        dont_upgrade=(not state.installstate.keep_outdated),
         user=user,
         clear=state.clear,
         unused=unused,
@@ -687,6 +653,7 @@ def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
         system=state.system,
         extra_pip_args=state.installstate.extra_pip_args,
         categories=state.installstate.categories,
+        site_packages=state.site_packages,
     )
     if retcode:
         ctx.abort()
@@ -722,18 +689,17 @@ def clean(state, dry_run=False, bare=False, user=False):
 def scripts(state):
     """Lists scripts in current environment config."""
     if not state.project.pipfile_exists:
-        echo("No Pipfile present at project home.", err=True)
+        err.print("No Pipfile present at project home.")
         sys.exit(1)
     scripts = state.project.parsed_pipfile.get("scripts", {})
     first_column_width = max(len(word) for word in ["Command"] + list(scripts))
     second_column_width = max(len(word) for word in ["Script"] + list(scripts.values()))
-    lines = ["{0:<{width}}  Script".format("Command", width=first_column_width)]
-    lines.append("{}  {}".format("-" * first_column_width, "-" * second_column_width))
+    lines = [f"{command:<{first_column_width}}  Script" for command in ["Command"]]
+    lines.append(f"{'-' * first_column_width}  {'-' * second_column_width}")
     lines.extend(
-        "{0:<{width}}  {1}".format(name, script, width=first_column_width)
-        for name, script in scripts.items()
+        f"{name:<{first_column_width}}  {script}" for name, script in scripts.items()
     )
-    echo("\n".join(line for line in lines))
+    console.print("\n".join(line for line in lines))
 
 
 @cli.command(
@@ -744,17 +710,14 @@ def scripts(state):
 def verify(state):
     """Verify the hash in Pipfile.lock is up-to-date."""
     if not state.project.pipfile_exists:
-        echo("No Pipfile present at project home.", err=True)
+        err.print("No Pipfile present at project home.")
         sys.exit(1)
     if state.project.get_lockfile_hash() != state.project.calculate_pipfile_hash():
-        echo(
-            "Pipfile.lock is out-of-date. Run {} to update.".format(
-                style("$ pipenv lock", fg="yellow", bold=True)
-            ),
-            err=True,
+        err.print(
+            "Pipfile.lock is out-of-date. Run [yellow bold]$ pipenv lock[/yellow bold] to update."
         )
         sys.exit(1)
-    echo(style("Pipfile.lock is up-to-date.", fg="green"))
+    console.print("Pipfile.lock is up-to-date.", style="green")
     sys.exit(0)
 
 
@@ -778,58 +741,33 @@ def verify(state):
 def requirements(
     state, dev=False, dev_only=False, hash=False, exclude_markers=False, categories=""
 ):
-    from pipenv.utils.dependencies import convert_deps_to_pip
+    from pipenv.routines.requirements import generate_requirements
 
-    lockfile = state.project.load_lockfile(expand_env_vars=False)
-
-    for i, package_index in enumerate(lockfile["_meta"]["sources"]):
-        prefix = "-i" if i == 0 else "--extra-index-url"
-        echo(" ".join([prefix, package_index["url"]]))
-
-    deps = {}
-    categories_list = re.split(r", *| ", categories) if categories else []
-
-    if categories_list:
-        for category in categories_list:
-            category = get_lockfile_section_using_pipfile_category(category.strip())
-            deps.update(lockfile.get(category, {}))
-    else:
-        if dev or dev_only:
-            deps.update(lockfile["develop"])
-        if not dev_only:
-            deps.update(lockfile["default"])
-
-    pip_deps = convert_deps_to_pip(
-        deps,
-        project=None,
-        include_index=False,
+    generate_requirements(
+        project=state.project,
+        dev=dev,
+        dev_only=dev_only,
         include_hashes=hash,
         include_markers=not exclude_markers,
+        categories=categories,
     )
 
-    for d in pip_deps:
-        echo(d)
-
-    sys.exit(0)
-
 
 if __name__ == "__main__":
     cli()
 
 
-def do_py(project, ctx=None, system=False):
+def do_py(project, ctx=None, system=False, bare=False):
     if not project.virtualenv_exists:
-        click.echo(
-            "{}({}){}".format(
-                click.style("No virtualenv has been created for this project ", fg="red"),
-                click.style(project.project_directory, fg="yellow", bold=True),
-                click.style(" yet!", fg="red"),
-            ),
-            err=True,
+        err.print(
+            "[red]No virtualenv has been created for this project[/red] "
+            f"[yellow bold]{project.project_directory}[/yellow bold] "
+            "[red] yet![/red]"
         )
         ctx.abort()
 
     try:
-        click.echo(project._which("python", allow_global=system))
+        (print if bare else console.print)(project._which("python", allow_global=system))
     except AttributeError:
-        click.echo(click.style("No project found!", fg="red"))
+        console.print("No project found!", style="red")
+        ctx.abort()
